Changelog
=========

0.4
---

- Improves the flexibility of getting/setting a widget

0.3
---

- Adds the ability to set/get widget values in a briefer form

0.2
---

- Adds the ability to set date in addition to datetime [href]

0.1
---

- Initial Release [href]
